IsNumber class

Inheritance

Constructors

IsNumber({bool isOptional = false, required dynamic value, String? propertyName, bool isNegative = false, bool isPositive = false, int? isDivisibleBy, int? max, int? min})

Properties

hashCode int
The hash code for this object.
no setterinherited
incorrectMaxRangeInvalidMessage String?
no setter
incorrectMinRangeInvalidMessage String?
no setter
invalidNumberMessage String?
no setter
isDivisibleBy int?
getter/setter pair
isNegative bool
getter/setter pair
isOptional bool
getter/setter pair
isPositive bool
getter/setter pair
max int?
getter/setter pair
min int?
getter/setter pair
notDivisibleByMessage String?
no setter
notNegativeMessage String?
no setter
notPositiveMessage String?
no setter
propertyName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
getter/setter pair

Methods

getMessage(String message) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() ValidationResult
override

Operators

operator ==(Object other) bool
The equality operator.
inherited