IsBoolean class
- Inheritance
-
- Object
- PropertyValidate
- IsBoolean
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidBooleanMessage → String?
-
no setter
- isOptional ↔ bool
-
getter/setter pair
- propertyName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ dynamic
-
getter/setter pair
Methods
-
getMessage(
String message) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → ValidationResult -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited