IsString class
- Inheritance
-
- Object
- PropertyValidate
- IsString
Constructors
-
IsString({bool isOptional = false, required dynamic value, String? propertyName, String? contains, String? notContains, bool ignoreCase = false, bool isEmail = false, bool isUrl = false, bool isAlpha = false, bool isAlphanumeric = false, bool isBase64 = false, bool isCreditCard = false, bool isDate = false, bool isJSON = false, bool isLowercase = false, bool isUUID = false, bool isIP = false, bool isUppercase = false, List<
String> isIn = const [], int? length, int? maxLen, int? minLen})
Properties
- contains ↔ String?
-
getter/setter pair
- containsInvalidMessage → String?
-
no setter
- emptyStringMessage → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreCase ↔ bool
-
getter/setter pair
- incorrectBase64Message → String?
-
no setter
- incorrectCreditCardMessage → String?
-
no setter
- incorrectDateMessage → String?
-
no setter
- incorrectIPMessage → String?
-
no setter
- incorrectIsAlphaMessage → String?
-
no setter
- incorrectIsAlphaNumericMessage → String?
-
no setter
- incorrectIsInMessage → String?
-
no setter
- incorrectJSONMessage → String?
-
no setter
- incorrectLengthInvalidMessage → String?
-
no setter
- incorrectLowercaseMessage → String?
-
no setter
- incorrectMatchMessage → String?
-
no setter
- incorrectMaxLengthInvalidMessage → String?
-
no setter
- incorrectMinLengthInvalidMessage → String?
-
no setter
- incorrectUppercaseMessage → String?
-
no setter
- incorrectUrlMessage → String?
-
no setter
- incorrectUUIDMessage → String?
-
no setter
- invalidStringMessage → String?
-
no setter
- isAlpha ↔ bool
-
getter/setter pair
- isAlphanumeric ↔ bool
-
getter/setter pair
- isBase64 ↔ bool
-
getter/setter pair
- isCreditCard ↔ bool
-
getter/setter pair
- isDate ↔ bool
-
getter/setter pair
- isEmail ↔ bool
-
getter/setter pair
-
isIn
↔ List<
String> -
getter/setter pair
- isIP ↔ bool
-
getter/setter pair
- isJSON ↔ bool
-
getter/setter pair
- isLowercase ↔ bool
-
getter/setter pair
- isOptional ↔ bool
-
getter/setter pair
- isUppercase ↔ bool
-
getter/setter pair
- isUrl ↔ bool
-
getter/setter pair
- isUUID ↔ bool
-
getter/setter pair
- length ↔ int?
-
getter/setter pair
- matches ↔ String?
-
getter/setter pair
- maxLen ↔ int?
-
getter/setter pair
- minLen ↔ int?
-
getter/setter pair
- notContains ↔ String?
-
getter/setter pair
- notContainsInvalidMessage → String?
-
no setter
- notEmailInvalidMessage → String?
-
no setter
- propertyName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ dynamic
-
getter/setter pair
Methods
-
getMessage(
String message) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → ValidationResult -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited